SpaCy-wrap
================================

.. image:: https://img.shields.io/github/stars/kennethenevoldsen/spacy-wrap.svg?style=social&label=Star&maxAge=2592000
   :target: https://github.com/kennethenevoldsen/spacy-wrap


spaCy-wrap is minimal library intended for wrapping fine-tuned transformers from the
`Huggingface model hub <https://huggingface.co/models?pipeline_tag=text-classification&sort=downloads>`__
in your spaCy pipeline allowing inclusion of existing models within `SpaCy <https://spacy.io>`__ workflows. 

As for as possible it follows a similar API as `spacy-transformers <https://github.com/explosion/spacy-transformers>`__.



Where to ask questions?
^^^^^^^^^^^^^^^^^^^^^^^^

To ask report issues or request features, please use the
`GitHub Issue Tracker <https://github.com/KennethEnevoldsen/spacy-wrap/issues>`__.
Questions related to SpaCy are kindly referred to the SpaCy GitHub or forum. Otherwise,
please use the discussion Forums.

+------------------------------+-------------------------+
| Type                         |                         |
+------------------------------+-------------------------+
| **Bug Reports**              | `GitHub Issue Tracker`_ |
+------------------------------+-------------------------+
| **Feature Requests & Ideas** | `GitHub Issue Tracker`_ |
+------------------------------+-------------------------+
| **Usage Questions**          | `GitHub Discussions`_   |
+------------------------------+-------------------------+
| **General Discussion**       | `GitHub Discussions`_   |
+------------------------------+-------------------------+


.. _GitHub Issue Tracker: https://github.com/KennethEnevoldsen/spacy-wrap/issues
.. _GitHub Discussions: https://github.com/KennethEnevoldsen/spacy-wrap/discussions


Acknowledgements
^^^^^^^^^^^^^^^^^^^^

Spacy-wrap modifies pre-existing code from spacy-transformers and thus a large part of
the credit goes to the Explosion team. Similarly, the library utilizes models available
on the Huggingface Hub, thus wrapped pipelines should be attributed to the respective
authors.

.. toctree::
   :maxdepth: 3
   :caption: Getting started
   :hidden:

   installation
   wrap.pipeline_component

.. toctree::
   :caption: News
   :hidden:

   news

.. toctree::
   :caption: FAQ
   :hidden:

   faq

.. toctree::
   :caption: GitHub
   :hidden:

   GitHub Repository <https://github.com/kennethenevoldsen/spacy-wrap>


Indices and search
==================

* :ref:`genindex`
* :ref:`search`

